@@ -60,10 +60,10 @@ fn find_leptonica_system_lib() -> Option<String> {
     println!("cargo:rustc-link-lib={}", pk.libs[0]);
 
     let mut include_path = pk.include_paths[0].clone();
-    // The include file used in this project has "leptonica" as part of
-    // the header file already
-    include_path.pop();
-    Some(include_path.to_string_lossy().to_string())
+    if include_path.ends_with("leptonica") {
+        include_path.pop();
+    }
+    Some(include_path.to_str().unwrap().into())
 }
 
 #[cfg(all(not(windows), not(target_os = "macos"), not(target_os = "linux")))]
